@@ -3,9 +3,10 @@ from math import sin,cos
 
 from scipy.stats import gmean, hmean
 from scipy.fft import fftn
+from numpy.linalg import norm
 from numpy import (
     ndarray, concatenate, argmax, array,
-    zeros, mean, max, min, sum, pad, norm
+    zeros, mean, max, min, sum, pad
 )
 
 from ffast.poincare.token import Token
